@@ -51,8 +51,7 @@ def add_args(parser):
                              "YAML/JSON")
     parser.add_argument("-i", "--inventory", metavar="INVENTORY",
                         help="specify inventory host path "
-                             "(default=$%s/inventory or %s/inventory) or "
-                             "comma-separated host list" %
+                             "(default=$%s/inventory or %s/inventory) " %
                              (CONFIG_PATH_ENV, DEFAULT_CONFIG_PATH))
     parser.add_argument("-l", "--limit", metavar="SUBSET",
                         help="further limit selected hosts to an additional "
@@ -146,8 +145,8 @@ def build_args(parsed_args, playbooks,
     if check or (parsed_args.check and check is None):
         cmd += ["--check"]
     if not ignore_limit and (parsed_args.limit or limit):
-        limits = [l for l in [parsed_args.limit, limit] if l]
-        cmd += ["--limit", ":&".join(limits)]
+        limit_arg = utils.intersect_limits(parsed_args.limit, limit)
+        cmd += ["--limit", limit_arg]
     if parsed_args.skip_tags:
         cmd += ["--skip-tags", parsed_args.skip_tags]
     if parsed_args.tags or tags:
