@@ -50,15 +50,15 @@ def add_args(parser):
                              "YAML/JSON for Kolla Ansible")
     parser.add_argument("-ki", "--kolla-inventory", metavar="INVENTORY",
                         help="specify inventory host path "
-                             "(default=$%s/inventory or %s/inventory) or "
-                             "comma-separated host list for Kolla Ansible" %
+                             "(default=$%s/inventory or %s/inventory) for "
+                             "Kolla Ansible" %
                              (CONFIG_PATH_ENV, DEFAULT_CONFIG_PATH))
     parser.add_argument("-kl", "--kolla-limit", metavar="SUBSET",
                         help="further limit selected hosts to an additional "
                              "pattern")
     parser.add_argument("--kolla-skip-tags", metavar="TAGS",
-                        help="only run plays and tasks whose tags do not match"
-                             "these values in Kolla Ansible")
+                        help="only run plays and tasks whose tags do not "
+                             "match these values in Kolla Ansible")
     parser.add_argument("-kt", "--kolla-tags", metavar="TAGS",
                         help="only run plays and tasks tagged with these "
                              "values in Kolla Ansible")
@@ -87,7 +87,7 @@ def _validate_args(parsed_args, inventory_filename):
         sys.exit(1)
 
     inventory = _get_inventory_path(parsed_args, inventory_filename)
-    result = utils.is_readable_dir(parsed_args.kolla_venv)
+    result = utils.is_readable_dir(inventory)
     if not result["result"]:
         # NOTE(mgoddard): Previously the inventory was a file, now it is a
         # directory to allow us to support inventory host_vars. Support both
@@ -131,8 +131,8 @@ def build_args(parsed_args, command, inventory_filename, extra_vars=None,
             extra_var_value = utils.quote_and_escape(extra_var_value)
             cmd += ["-e", "%s=%s" % (extra_var_name, extra_var_value)]
     if parsed_args.kolla_limit or limit:
-        limits = [l for l in [parsed_args.kolla_limit, limit] if l]
-        cmd += ["--limit", ":&".join(limits)]
+        limit_arg = utils.intersect_limits(parsed_args.kolla_limit, limit)
+        cmd += ["--limit", utils.quote_and_escape(limit_arg)]
     if parsed_args.kolla_skip_tags:
         cmd += ["--skip-tags", parsed_args.kolla_skip_tags]
     if parsed_args.kolla_tags or tags:
