@@ -12,12 +12,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import os
 import subprocess
 import unittest
 
 import mock
 import yaml
 
+from kayobe import exception
 from kayobe import utils
 
 
@@ -114,3 +116,63 @@ key2: value2
         mock_call.side_effect = subprocess.CalledProcessError(1, "command")
         self.assertRaises(subprocess.CalledProcessError, utils.run_command,
                           ["command", "to", "run"])
+
+    def test_quote_and_escape_no_whitespace(self):
+        self.assertEqual("'foo'", utils.quote_and_escape("foo"))
+
+    def test_quote_and_escape_whitespace(self):
+        self.assertEqual("'foo bar'", utils.quote_and_escape("foo bar"))
+
+    def test_quote_and_escape_whitespace_with_quotes(self):
+        self.assertEqual("'foo '\\''bar'\\'''",
+                         utils.quote_and_escape("foo 'bar'"))
+
+    def test_quote_and_escape_non_string(self):
+        self.assertEqual(True, utils.quote_and_escape(True))
+
+    def test_escape_jinja(self):
+        value = "string to escape"
+        expected = "{{'c3RyaW5nIHRvIGVzY2FwZQ==' | b64decode }}"
+        self.assertEqual(expected, utils.escape_jinja(value))
+
+    def test_detect_install_prefix(self):
+        path = "/tmp/test/local/lib/python2.7/dist-packages"
+        expected = os.path.normpath("/tmp/test/local/")
+        result = utils._detect_install_prefix(path)
+        self.assertEqual(expected, os.path.normpath(result))
+
+    def test_intersect_limits_no_arg_no_cli(self):
+        result = utils.intersect_limits(None, None)
+        self.assertEqual("", result)
+
+    def test_intersect_limits_arg_no_cli(self):
+        result = utils.intersect_limits("foo", None)
+        self.assertEqual("foo", result)
+
+    def test_intersect_limits_arg_no_cli_comma(self):
+        result = utils.intersect_limits("foo,bar", None)
+        self.assertEqual("foo,bar", result)
+
+    def test_intersect_limits_arg_no_cli_colon(self):
+        result = utils.intersect_limits("foo:bar", None)
+        self.assertEqual("foo:bar", result)
+
+    def test_intersect_limits_arg_no_cli_colon_and_comma(self):
+        self.assertRaises(exception.Error,
+                          utils.intersect_limits, "foo:bar,baz", None)
+
+    def test_intersect_limits_no_arg_cli(self):
+        result = utils.intersect_limits(None, "foo")
+        self.assertEqual("foo", result)
+
+    def test_intersect_limits_arg_and_cli(self):
+        result = utils.intersect_limits("foo", "bar")
+        self.assertEqual("foo:&bar", result)
+
+    def test_intersect_limits_arg_and_cli_comma(self):
+        result = utils.intersect_limits("foo,bar", "baz")
+        self.assertEqual("foo,bar,&baz", result)
+
+    def test_intersect_limits_arg_and_cli_colon(self):
+        result = utils.intersect_limits("foo:bar", "baz")
+        self.assertEqual("foo:bar:&baz", result)
